﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication21
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            DefaultAppearance();
            CustomDataPointColor();

        }
        /// <summary>
        /// Builds chart with default appearance.
        /// </summary>
        void DefaultAppearance()
        {
            chart.Data.Children.Add(CreateDataSeries(50));
        }

        /// <summary>
        /// Builds chart with custom color of data points.
        /// </summary>
        void CustomDataPointColor()
        {
            var ds = CreateDataSeries(50);
            ds.PlotElementLoaded += (sender, args) =>
            {
                var pe = (C1.WPF.C1Chart.PlotElement)sender;
                var dp = pe.DataPoint;
                if (!(pe is C1.WPF.C1Chart.Lines)) // skip connecting lines
                {
                    // fill the symbol with color that is calculated from the data value
                    pe.Fill = GetBrush(Colors.Blue, Colors.White, Colors.Red, dp.Value);
                }
            };
            chart.Data.Children.Add(ds);
        }

        /// <summary>
        /// Creates sample data series.
        /// </summary>
        /// <param name="npts"></param>
        /// <returns></returns>
        C1.WPF.C1Chart.XYDataSeries CreateDataSeries(int npts)
        {
            double[] x = new double[npts];
            double[] y = new double[npts];
            for (int i = 0; i < npts; i++)
            {
                x[i] = 0.5 * i; y[i] = Math.Sin(x[i]);
            }

            return new C1.WPF.C1Chart.XYDataSeries() { XValuesSource = x, ValuesSource = y };
        }

        /// <summary>
        /// Create brush mixing three colors in the proportion specified by value(-1,+1).
        /// </summary>
        /// <param name="clr1"></param>
        /// <param name="clr2"></param>
        /// <param name="value"></param>
        /// <returns></returns>
        SolidColorBrush GetBrush(Color clr1, Color clr2, Color clr3, double value)
        {
            if (value > 0)
            {
                clr1 = clr2; clr2 = clr3;
            }

            Color clr = Color.FromArgb((byte)(clr1.A + value * (clr2.A - clr1.A)),
              (byte)(clr1.R + value * (clr2.R - clr1.R)),
              (byte)(clr1.G + value * (clr2.G - clr1.G)),
              (byte)(clr1.B + value * (clr2.B - clr1.B)));
            return new SolidColorBrush(clr);
        }
    }
}
